==> cupy-7.7.0.tar.gz: cupy-7.7.0/cupy/testing/__init__.py <==
from cupy.testing import array  # NOQA
from cupy.testing import attr  # NOQA
from cupy.testing import helper  # NOQA
from cupy.testing import parameterized  # NOQA
from cupy.testing import random  # NOQA

from cupy.testing.array import assert_allclose  # NOQA
from cupy.testing.array import assert_array_almost_equal  # NOQA
from cupy.testing.array import assert_array_almost_equal_nulp  # NOQA
from cupy.testing.array import assert_array_equal  # NOQA
from cupy.testing.array import assert_array_less  # NOQA
from cupy.testing.array import assert_array_list_equal  # NOQA
from cupy.testing.array import assert_array_max_ulp  # NOQA
from cupy.testing.attr import gpu  # NOQA
from cupy.testing.attr import multi_gpu  # NOQA
from cupy.testing.attr import slow  # NOQA
from cupy.testing.helper import assert_warns  # NOQA
from cupy.testing.helper import empty  # NOQA
from cupy.testing.helper import for_all_dtypes  # NOQA
from cupy.testing.helper import for_all_dtypes_combination  # NOQA
from cupy.testing.helper import for_CF_orders  # NOQA
from cupy.testing.helper import for_complex_dtypes  # NOQA
from cupy.testing.helper import for_dtypes  # NOQA
from cupy.testing.helper import for_dtypes_combination  # NOQA
from cupy.testing.helper import for_float_dtypes  # NOQA
from cupy.testing.helper import for_int_dtypes  # NOQA
from cupy.testing.helper import for_int_dtypes_combination  # NOQA
from cupy.testing.helper import for_orders  # NOQA
from cupy.testing.helper import for_signed_dtypes  # NOQA
from cupy.testing.helper import for_signed_dtypes_combination  # NOQA
from cupy.testing.helper import for_unsigned_dtypes  # NOQA
from cupy.testing.helper import for_unsigned_dtypes_combination  # NOQA
from cupy.testing.helper import numpy_cupy_allclose  # NOQA
from cupy.testing.helper import numpy_cupy_array_almost_equal  # NOQA
from cupy.testing.helper import numpy_cupy_array_almost_equal_nulp  # NOQA
from cupy.testing.helper import numpy_cupy_array_equal  # NOQA
from cupy.testing.helper import numpy_cupy_array_less  # NOQA
from cupy.testing.helper import numpy_cupy_array_list_equal  # NOQA
from cupy.testing.helper import numpy_cupy_array_max_ulp  # NOQA
from cupy.testing.helper import numpy_cupy_equal  # NOQA
from cupy.testing.helper import numpy_cupy_raises  # NOQA
from cupy.testing.helper import numpy_satisfies  # NOQA
from cupy.testing.helper import NumpyAliasBasicTestBase  # NOQA
from cupy.testing.helper import NumpyAliasValuesTestBase  # NOQA
from cupy.testing.helper import NumpyError  # NOQA
from cupy.testing.helper import shaped_arange  # NOQA
from cupy.testing.helper import shaped_random  # NOQA
from cupy.testing.helper import shaped_reverse_arange  # NOQA
from cupy.testing.helper import with_requires  # NOQA
from cupy.testing.parameterized import from_pytest_parameterize  # NOQA
from cupy.testing.parameterized import parameterize  # NOQA
from cupy.testing.parameterized import parameterize_pytest  # NOQA
from cupy.testing.parameterized import product  # NOQA
from cupy.testing.parameterized import product_dict  # NOQA
from cupy.testing.random import fix_random  # NOQA
from cupy.testing.random import generate_seed  # NOQA

==> cupy-9.0.0b3.tar.gz: cupy-9.0.0b3/cupy/testing/__init__.py <==
from cupy.testing import array  # NOQA
from cupy.testing import attr  # NOQA
from cupy.testing import helper  # NOQA
from cupy.testing import parameterized  # NOQA
from cupy.testing import random  # NOQA

from cupy.testing.array import assert_allclose  # NOQA
from cupy.testing.array import assert_array_almost_equal  # NOQA
from cupy.testing.array import assert_array_almost_equal_nulp  # NOQA
from cupy.testing.array import assert_array_equal  # NOQA
from cupy.testing.array import assert_array_less  # NOQA
from cupy.testing.array import assert_array_list_equal  # NOQA
from cupy.testing.array import assert_array_max_ulp  # NOQA
from cupy.testing.attr import gpu  # NOQA
from cupy.testing.attr import multi_gpu  # NOQA
from cupy.testing.attr import slow  # NOQA
from cupy.testing.helper import assert_warns  # NOQA
from cupy.testing.helper import for_all_dtypes  # NOQA
from cupy.testing.helper import for_all_dtypes_combination  # NOQA
from cupy.testing.helper import for_CF_orders  # NOQA
from cupy.testing.helper import for_complex_dtypes  # NOQA
from cupy.testing.helper import for_contiguous_axes  # NOQA
from cupy.testing.helper import for_dtypes  # NOQA
from cupy.testing.helper import for_dtypes_combination  # NOQA
from cupy.testing.helper import for_float_dtypes  # NOQA
from cupy.testing.helper import for_int_dtypes  # NOQA
from cupy.testing.helper import for_int_dtypes_combination  # NOQA
from cupy.testing.helper import for_orders  # NOQA
from cupy.testing.helper import for_signed_dtypes  # NOQA
from cupy.testing.helper import for_signed_dtypes_combination  # NOQA
from cupy.testing.helper import for_unsigned_dtypes  # NOQA
from cupy.testing.helper import for_unsigned_dtypes_combination  # NOQA
from cupy.testing.helper import numpy_cupy_allclose  # NOQA
from cupy.testing.helper import numpy_cupy_array_almost_equal  # NOQA
from cupy.testing.helper import numpy_cupy_array_almost_equal_nulp  # NOQA
from cupy.testing.helper import numpy_cupy_array_equal  # NOQA
from cupy.testing.helper import numpy_cupy_array_less  # NOQA
from cupy.testing.helper import numpy_cupy_array_list_equal  # NOQA
from cupy.testing.helper import numpy_cupy_array_max_ulp  # NOQA
from cupy.testing.helper import numpy_cupy_equal  # NOQA
from cupy.testing.helper import numpy_cupy_raises  # NOQA
from cupy.testing.helper import numpy_satisfies  # NOQA
from cupy.testing.helper import NumpyAliasBasicTestBase  # NOQA
from cupy.testing.helper import NumpyAliasValuesTestBase  # NOQA
from cupy.testing.helper import AssertFunctionIsCalled  # NOQA
from cupy.testing.helper import shaped_arange  # NOQA
from cupy.testing.helper import shaped_sparse_random  # NOQA
from cupy.testing.helper import shaped_random  # NOQA
from cupy.testing.helper import generate_matrix  # NOQA
from cupy.testing.helper import shaped_reverse_arange  # NOQA
from cupy.testing.helper import with_requires  # NOQA
from cupy.testing.parameterized import parameterize  # NOQA
from cupy.testing.parameterized import product  # NOQA
from cupy.testing.parameterized import product_dict  # NOQA
from cupy.testing.random import fix_random  # NOQA
from cupy.testing.random import generate_seed  # NOQA
